# scattermind

Scattermind is a decentralized and distributed horizontally scalable model
execution framework. Worried your model won't fit in memory? Scattermind
splits the model into small independently executable sub-models to accomodate
even small machines (*).

(*) Currently only available through plugins. Once the plugins have matured
they will be included in the main distribution.

## TODOs

A rough outline of planned features:

- node based caching
- record / replay inputs
- record / replay activity
- log granular activity
- split nodes
- benchmark
- diffusion model
- push notification on result
- computation timing estimates
- self configuration
- config hotloading
- model training
